Changelog class

Annotations
  • @freezed

Constructors

Changelog({required String id, required String title, required String content, String? featuredImage, required String organization, required String state, required String locale, required List<ChangelogCategory> changelogCategories, required DateTime date, required String slug, required bool isDraftDiffersFromLive, required bool isPublished, required List<String> availableLocales, required List<String> publishedLocales})
const
factory
Changelog.fromJson(Map<String, Object?> json)
factory

Properties

availableLocales → List<String>
An array of available locales for the changelog.
no setterinherited
changelogCategories → List<ChangelogCategory>
The categories of the changelog.
no setterinherited
content → String
The content of the changelog.
no setterinherited
copyWith → $ChangelogCopyWith<Changelog>
Create a copy of Changelog with the given fields replaced by the non-null parameter values.
no setterinherited
date → DateTime
The date when the Changelog was created.
no setterinherited
featuredImage → String?
The featured image of the changelog.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique ID.
no setterinherited
isDraftDiffersFromLive → bool
Indicates whether the draft version differs from the live published version.
no setterinherited
isPublished → bool
Indicates whether the changelog is published.
no setterinherited
locale → String
The locale of the changelog.
no setterinherited
organization → String
The ID of the organization that the changelog belongs to.
no setterinherited
publishedLocales → List<String>
An array of locales in which the changelog is published.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slug → String
The URL-friendly slug of the changelog.
no setterinherited
state → String
The state of the changelog, either "live" or "draft".
no setterinherited
title → String
The title of the changelog.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Changelog to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited