ChangelogCategory class

Annotations
  • @freezed

Constructors

ChangelogCategory({required String name, required String color})
const
factory
ChangelogCategory.fromJson(Map<String, Object?> json)
factory

Properties

color → String
Changelog category color
no setterinherited
copyWith → $ChangelogCategoryCopyWith<ChangelogCategory>
Create a copy of ChangelogCategory with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
Changelog category name
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ChangelogCategory to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited