Collection class
Constructors
-
Collection({required String collectionId, required String name, required String description, required String? parentId, required FBIcon? icon, required String helpCenterId, required String organizationId, required String defaultLocale, int? order, required String type, required String path, required String slug, required String featurebaseUrl, required String? externalUrl, required String locale, List<Author>? authors, required List<String> availableLocales, List<CollectionContent>? structure})
-
const
factory
-
Collection.fromJson(Map<String, Object?> json)
-
factory
Properties
-
authors
→ List<Author>?
-
Authors of the article (will be null if hideAuthorInfo is true)
no setterinherited
-
availableLocales
→ List<String>
-
An array of available locales for the collection.
no setterinherited
-
collectionId
→ String
-
The collection's unique ID.
no setterinherited
-
copyWith
→ $CollectionCopyWith<Collection>
-
Create a copy of Collection
with the given fields replaced by the non-null parameter values.
no setterinherited
-
defaultLocale
→ String
-
The default locale of the collection.
no setterinherited
-
description
→ String
-
A description of the collection.
no setterinherited
-
externalUrl
→ String?
-
The custom domain URL for the collection.
no setterinherited
-
featurebaseUrl
→ String
-
The Featurebase URL for the collection.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
helpCenterId
→ String
-
The ID of the help center this collection belongs to.
no setterinherited
-
icon
→ FBIcon?
-
The icon of the collection.
no setterinherited
-
locale
→ String
-
The locale of the collection.
no setterinherited
-
name
→ String
-
The name of the collection.
no setterinherited
-
order
→ int?
-
The order of the collection in listings.
no setterinherited
-
organizationId
→ String
-
The ID of the organization that the collection belongs to.
no setterinherited
-
parentId
→ String?
-
The ID of the parent collection, if the collection is nested.
no setterinherited
-
path
→ String
-
The path to the collection within the help center hierarchy.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
slug
→ String
-
The URL-friendly slug of the collection.
no setterinherited
-
structure
→ List<CollectionContent>?
-
List of articles and collections (only returned when using the withStructure option)
no setterinherited
-
type
→ String
-
The type of the document, which is "collection".
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Serializes this Collection to a JSON map.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited