ConversationPart class

Annotations
  • @freezed

Constructors

ConversationPart({required String id, required String partType, required String body, String? bodyText, String? channel, required DateTime createdAt, required ConversationParticipant? author})
const
factory
ConversationPart.fromJson(Map<String, Object?> json)
factory

Properties

author → ConversationParticipant?
Who the author of the part is
no setterinherited
body → String
Full body
no setterinherited
bodyText → String?
Body converted to text
no setterinherited
channel → String?
Conversation channel
no setterinherited
copyWith → $ConversationPartCopyWith<ConversationPart>
Create a copy of ConversationPart with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
When the part was created
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
Part Id
no setterinherited
partType → String
Part type
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ConversationPart to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited