Inbox class

Annotations
  • @freezed

Constructors

Inbox({required int count, required String name, required String id, required String type})
const
factory
Inbox.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $InboxCopyWith<Inbox>
Create a copy of Inbox with the given fields replaced by the non-null parameter values.
no setterinherited
count → int
Inbox item count
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
Inbox Id
no setterinherited
name → String
Inbox name
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Inbox type
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Inbox to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited