Organization class
- Annotations
-
- @freezed
Constructors
-
Organization({required String name, required String displayName, required String color, String? ssoUrl, String? customDomain, AIOWidget? widget, required OrganizationSettings settings, required List<
PostCategory> postCategories, String? picture}) -
constfactory
-
Organization.fromJson(Map<
String, Object?> json) -
factory
Properties
- color → String
-
Color hash code
no setterinherited
-
copyWith
→ $OrganizationCopyWith<
Organization> -
Create a copy of Organization
with the given fields replaced by the non-null parameter values.
no setterinherited
- customDomain → String?
-
Custom domain
no setterinherited
- displayName → String
-
The display name of the organization
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the organization
no setterinherited
- picture → String?
-
Picture url
no setterinherited
-
postCategories
→ List<
PostCategory> -
The post categories of the organization
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → OrganizationSettings
-
The settings of the organization
no setterinherited
- ssoUrl → String?
-
SSO Url
no setterinherited
- widget → AIOWidget?
-
The widgets of the organization
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Organization to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited