PostStatus class

Annotations
  • @freezed

Constructors

PostStatus({required String name, required String color, required String type, @Default.new(false) bool isDefault})
const
factory
PostStatus.fromJson(Map<String, Object?> json)
factory

Properties

color → String
The status color
no setterinherited
copyWith → $PostStatusCopyWith<PostStatus>
Create a copy of PostStatus with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isDefault → bool
If the status is the default status
no setterinherited
name → String
The status name
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The status type
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this PostStatus to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited