ResultsPagination<T> class

Annotations
  • @JsonSerializable.new(createToJson: false, genericArgumentFactories: true)

Constructors

ResultsPagination(List<T> results, int page, int limit, int totalPages, int totalResults)
ResultsPagination.fromJson(Map<String, dynamic> json, T fromJsonT(Object?))
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit ↔ int
The limit of the pagination.
getter/setter pair
page ↔ int
The current page number.
getter/setter pair
results ↔ List<T>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalPages ↔ int
The total number of pages.
getter/setter pair
totalResults ↔ int
The total number of items.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited