User class

Annotations
  • @freezed

Constructors

User({required String id, String? userId, required String name, String? picture, @Default.new(0) int commentsCreated, @Default.new(0) int postsCreated, required String type})
const
factory
User.fromJson(Map<String, Object?> json)
factory

Properties

commentsCreated → int
The amount of comments the user has created
no setterinherited
copyWith → $UserCopyWith<User>
Create a copy of User with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
The featurebase id for the user
no setterinherited
name → String
The name of the user
no setterinherited
picture → String?
The users picture
no setterinherited
postsCreated → int
The amount of posts the user has created
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of the user
no setterinherited
userId → String?
The platforms user id
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this User to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited