UserSimple class

Annotations
  • @freezed

Constructors

UserSimple({required String id, required String type, required String name, String? picture})
const
factory
UserSimple.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $UserSimpleCopyWith<UserSimple>
Create a copy of UserSimple with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
The id of the user
no setterinherited
name → String
The name of the user
no setterinherited
picture → String?
The users picture
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of the user
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this UserSimple to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited