UserWithAuth class

Annotations
  • @freezed

Constructors

UserWithAuth({required String id, required String name, required String email, String? picture, required String type, required String accessToken})
const
factory
UserWithAuth.fromJson(Map<String, Object?> json)
factory

Properties

accessToken → String
The user access tken
no setterinherited
copyWith → $UserWithAuthCopyWith<UserWithAuth>
Create a copy of UserWithAuth with the given fields replaced by the non-null parameter values.
no setterinherited
email → String
The users email
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
The featurebase id for the user
no setterinherited
name → String
The name of the user
no setterinherited
picture → String?
The users picture
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of the user
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this UserWithAuth to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited